import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.nio.charset.Charset;

/**
 * 日本語ファイルを読み書きする場合，InputStreamReader, OutputStreamWriterを使い，
 * 読むファイルの文字コード，書きだしたい文字コードを指定する必要がある．
 * 入力文字の自動判別を行うフリーソフトも存在するらしいが，基本は読むファイルのコードの認識が必要．
 * 標準の自動判別エンコーディングである JISAutoDetect は UTF-8/UTF-16 を判別しないので使い物にならない．
 * 尚，コンソール出力の場合，当該端末のデフォルトエンコーディングが使われるので，読み込みに成功すれば，大抵，問題ない．
 * また，Stringとして読み込まれてしまえば内部エンコーディングになってるので，比較やマッチも簡単．
 * @author kaiya
 *
 */
public class Test {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		String conCode=Charset.defaultCharset().displayName();
		String inputCode="UTF8";
		String outputCode="MS932";
		System.out.printf("Input = %s, Output = %s, Default= %s\n", inputCode, outputCode, conCode);

		try {
			// ファイルをオープンする 旧来の方法
			//FileReader fr=new FileReader("input.txt");
			//System.out.printf("InputEncoding = %s\n", fr.getEncoding());
			// ファイルをオープン encoding指定
			FileInputStream fis=new FileInputStream("input.txt");
			InputStreamReader isr=new InputStreamReader(fis, inputCode);
			BufferedReader br = new BufferedReader(isr);
			// ファイルをオープンする
			//FileWriter fw=new FileWriter("output.txt");
			//System.out.printf("OutputEncoding = %s\n", fw.getEncoding());
			// ファイル書き込み encoding指定
			FileOutputStream fos=new FileOutputStream("output.txt");
			OutputStreamWriter osw=new OutputStreamWriter(fos, outputCode);
			PrintWriter pr = new PrintWriter(new BufferedWriter(osw));

			// ファイルを読み込む
			String line;
			// String code = "UTF8";
			while ((line = br.readLine()) != null) {
				//String outStr = new String(line.getBytes(code), code);
				if(line.matches("^.*テスト.*$")){
					System.out.print("* ");
				}
				System.out.println(line); // 端末のデフォルトエンコーディングで出力される
				pr.println(line);
			}

			// ファイルをクローズする
			br.close();
			pr.close();

		} catch (Exception e) {
			System.err.println(e.toString());
		}

	}

}
